@@ -7,38 +7,39 @@ from .shade import Shade
 class _BaseWithShade(_Base):
     """A base class for all objects that can have Shades nested on them.
 
+    Args:
+        identifier: Text string for a unique object ID. Must be < 100 characters and
+            not contain any spaces or special characters.
+
     Properties:
-        name
-        display_name
-        geometry
-        outdoor_shades
-        indoor_shades
+        * identifier
+        * display_name
+        * geometry
+        * outdoor_shades
+        * indoor_shades
+        * shades
     """
     __slots__ = ('_outdoor_shades', '_indoor_shades')
 
-    def __init__(self, name):
-        """Initialize base with shade object.
-
-        Args:
-            name: Object name. Must be < 100 characters.
-        """
-        _Base.__init__(self, name)  # process the name
+    def __init__(self, identifier):
+        """Initialize base with shade object."""
+        _Base.__init__(self, identifier)  # process the identifier
         self._outdoor_shades = []
         self._indoor_shades = []
 
     @property
     def outdoor_shades(self):
-        """Array of all outdoor shades assigned to this object."""
+        """Get an array of all outdoor shades assigned to this object."""
         return tuple(self._outdoor_shades)
 
     @property
     def indoor_shades(self):
-        """Array of all indoor shades assigned to this object."""
+        """Get an array of all indoor shades assigned to this object."""
         return tuple(self._indoor_shades)
 
     @property
     def shades(self):
-        """Array of all shades (both indoor and outdoor) assigned to this object."""
+        """Get an array of all shades (indoor + outdoor) assigned to this object."""
         return self._outdoor_shades + self._indoor_shades
 
     def remove_shades(self):
@@ -56,31 +57,34 @@ class _BaseWithShade(_Base):
         """Remove all indoor shades assigned to this object."""
         for shade in self._indoor_shades:
             shade._parent = None
+            shade._is_indoor = False
         self._indoor_shades = []
 
     def add_outdoor_shade(self, shade):
-        """Add a Shade object to the outdoor of this object.
+        """Add a Shade object to the outdoors of this object.
 
-        Outdoor Shade objects can be used to represent overhangs, fins, etc.
+        Outdoor Shade objects can be used to represent balconies, outdoor furniture,
+        overhangs, light shelves, fins, the exterior part of mullions, etc.
         For representing larger shade objects like trees or other buildings,
         it may be more appropriate to add them to the Model as orphaned_shades
         without a specific parent object.
 
         Args:
-            shade: A shade face to add to the outdoors of this object.
+            shade: A Shade object to add to the outdoors of this object.
         """
         assert isinstance(shade, Shade), \
             'Expected Shade for outdoor_shade. Got {}.'.format(type(shade))
+        assert shade.parent is None, 'Shade cannot have more than one parent object.'
         shade._parent = self
         self._outdoor_shades.append(shade)
 
     def add_indoor_shade(self, shade):
-        """Add a Shade object to be added to the indoor of this object.
+        """Add a Shade object to be added to the indoors of this object.
 
         Indoor Shade objects can be used to represent furniture, the interior
-        part of light shelves, etc.
+        portion of light shelves, the interior part of mullions, etc.
         For representing finely detailed objects like blinds or roller shades,
-        it may be more apprpriate to model them as materials assigned to
+        it may be more appropriate to model them as materials assigned to
         Aperture properties (like Radiance materials or Energy constructions).
 
         Args:
@@ -88,9 +92,29 @@ class _BaseWithShade(_Base):
         """
         assert isinstance(shade, Shade), \
             'Expected Shade for indoor_shade. Got {}.'.format(type(shade))
+        assert shade.parent is None, 'Shade cannot have more than one parent object.'
         shade._parent = self
+        shade._is_indoor = True
         self._indoor_shades.append(shade)
 
+    def add_outdoor_shades(self, shades):
+        """Add a list of Shade objects to the outdoors of this object.
+
+        Args:
+            shades: A list of Shade objects to add to the outdoors of this object.
+        """
+        for shade in shades:
+            self.add_outdoor_shade(shade)
+
+    def add_indoor_shades(self, shades):
+        """Add a list of Shade objects to the indoors of this object.
+
+        Args:
+            shades: A list of Shade objects to add to the indoors of this object.
+        """
+        for shade in shades:
+            self.add_indoor_shade(shade)
+
     def move_shades(self, moving_vec):
         """Move all indoor and outdoor shades assigned to this object along a vector.
 
@@ -155,6 +179,18 @@ class _BaseWithShade(_Base):
         for ishd in self._indoor_shades:
             ishd.scale(factor, origin)
 
+    def _add_prefix_shades(self, prefix):
+        """Change the name of all child shades by inserting a prefix.
+
+        Args:
+            prefix: Text that will be inserted at the start of this shades' name
+                and display_name.
+        """
+        for shade in self._outdoor_shades:
+            shade.add_prefix(prefix)
+        for shade in self._indoor_shades:
+            shade.add_prefix(prefix)
+
     def _check_planar_shades(self, tolerance, raise_exception=True):
         """Check that all of the child shades are planar."""
         for oshd in self._outdoor_shades:
@@ -186,13 +222,13 @@ class _BaseWithShade(_Base):
         return True
 
     def _add_shades_to_dict(self, base, abridged=False, included_prop=None):
-        """Method used to add child shades to the paret base dictionary.
+        """Method used to add child shades to the parent base dictionary.
 
         Args:
             base: The base object dictionary to which the child shades will be added.
             abridged: Boolean to note whether the extension properties of the
                 object should be included in detail (False) or just referenced by
-                name (True). Default: False.
+                identifier (True). Default: False.
             included_prop: List of properties to filter keys that must be included in
                 output dictionary. For example ['energy'] will include 'energy' key if
                 available in properties to_dict. By default all the keys will be
@@ -220,12 +256,14 @@ class _BaseWithShade(_Base):
             self._indoor_shades = [Shade.from_dict(sh) for sh in data['indoor_shades']]
             for ishd in self._indoor_shades:
                 ishd._parent = self
+                ishd._is_indoor = True
 
     def _duplicate_child_shades(self, new_object):
-        """Add duplicated child shades to a duplcated new_object."""
+        """Add duplicated child shades to a duplicated new_object."""
         new_object._outdoor_shades = [oshd.duplicate() for oshd in self._outdoor_shades]
         new_object._indoor_shades = [ishd.duplicate() for ishd in self._indoor_shades]
         for oshd in new_object._outdoor_shades:
             oshd._parent = new_object
         for ishd in new_object._indoor_shades:
             ishd._parent = new_object
+            ishd._is_indoor = True
