@@ -8,7 +8,7 @@ from .shade import Shade
 import honeybee.writer.aperture as writer
 
 from ladybug_geometry.geometry2d.pointvector import Vector2D
-from ladybug_geometry.geometry3d.pointvector import Point3D, Vector3D
+from ladybug_geometry.geometry3d.pointvector import Point3D
 from ladybug_geometry.geometry3d.face import Face3D
 
 import math
@@ -75,6 +75,7 @@ class Aperture(_BaseWithShade):
         assert data['type'] == 'Aperture', 'Expected Aperture dictionary. ' \
             'Got {}.'.format(data['type'])
 
+        # serialize the aperture
         is_operable = data['is_operable'] if 'is_operable' in data else False
         if data['boundary_condition']['type'] == 'Outdoors':
             boundary_condition = Outdoors.from_dict(data['boundary_condition'])
@@ -92,6 +93,7 @@ class Aperture(_BaseWithShade):
             aperture.user_data = data['user_data']
         aperture._recover_shades_from_dict(data)
 
+        # assign extension properties
         if data['properties']['type'] == 'ApertureProperties':
             aperture.properties._load_extension_attr_from_dict(data['properties'])
         return aperture
@@ -553,6 +555,18 @@ class Aperture(_BaseWithShade):
         self.scale_shades(factor, origin)
         self.properties.scale(factor, origin)
 
+    def remove_colinear_vertices(self, tolerance=0.01):
+        """Remove all colinear and duplicate vertices from this object's geometry.
+
+        Note that this does not affect any assigned Shades.
+
+        Args:
+            tolerance: The minimum distance between a vertex and the boundary segments
+                at which point the vertex is considered colinear. Default: 0.01,
+                suitable for objects in meters.
+        """
+        self._geometry = self.geometry.remove_colinear_vertices(tolerance)
+
     def check_planar(self, tolerance=0.01, raise_exception=True):
         """Check whether all of the Aperture's vertices lie within the same plane.
 
